@@ -1,9 +1,10 @@
 /*
- * Copyright 2001-2004 The Apache Software Foundation.
- * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
@@ -33,7 +34,7 @@ import junit.framework.TestSuite;
  * Test accessing DynaBeans transparently via PropertyUtils.
  *
  * @author Craig R. McClanahan
- * @version $Revision: 1.12 $ $Date: 2004/02/28 13:18:36 $
+ * @version $Revision: 471138 $ $Date: 2006-11-04 08:06:03 +0000 (Sat, 04 Nov 2006) $
  */
 
 public class DynaPropertyUtilsTestCase extends TestCase {
@@ -124,7 +125,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         listIndexed.add("String 3");
         listIndexed.add("String 4");
         bean.set("listIndexed", listIndexed);
-        bean.set("longProperty", new Long((long) 321));
+        bean.set("longProperty", new Long(321));
         HashMap mapProperty = new HashMap();
         mapProperty.put("First Key", "First Value");
         mapProperty.put("Second Key", "Second Value");
@@ -214,7 +215,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                      (float) 0.005);
         assertEquals("intProperty", 111,
                      ((Integer) bean.get("intProperty")).intValue());
-        assertEquals("longProperty", (long) 444,
+        assertEquals("longProperty", 444,
                      ((Long) bean.get("longProperty")).longValue());
         assertEquals("shortProperty", (short) 555,
                      ((Short) bean.get("shortProperty")).shortValue());
@@ -260,23 +261,17 @@ public class DynaPropertyUtilsTestCase extends TestCase {
 
         // Verify the values of scalar properties
         assertEquals("Value of 'booleanProperty'",
-                     Boolean.TRUE,
-                     (Boolean) map.get("booleanProperty"));
+                     Boolean.TRUE, map.get("booleanProperty"));
         assertEquals("Value of 'doubleProperty'",
-                     new Double(321.0),
-                     (Double) map.get("doubleProperty"));
+                     new Double(321.0), map.get("doubleProperty"));
         assertEquals("Value of 'floatProperty'",
-                     new Float((float) 123.0),
-                     (Float) map.get("floatProperty"));
+                     new Float((float) 123.0), map.get("floatProperty"));
         assertEquals("Value of 'intProperty'",
-                     new Integer(123),
-                     (Integer) map.get("intProperty"));
+                     new Integer(123), map.get("intProperty"));
         assertEquals("Value of 'longProperty'",
-                     new Long(321),
-                     (Long) map.get("longProperty"));
+                     new Long(321), map.get("longProperty"));
         assertEquals("Value of 'shortProperty'",
-                     new Short((short) 987),
-                     (Short) map.get("shortProperty"));
+                     new Short((short) 987), map.get("shortProperty"));
         assertEquals("Value of 'stringProperty'",
                      "This is a string",
                      (String) map.get("stringProperty"));
@@ -295,7 +290,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(null, "intArray", 0);
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -304,7 +299,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(bean, null, 0);
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -316,7 +311,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "intArray[0]");
             fail("Should throw IllegalArgumentException 3");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 3");
         }
@@ -325,7 +320,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(bean, "[0]");
             fail("Should throw NoSuchMethodException 4");
         } catch (NoSuchMethodException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of NoSuchMethodException 4");
         }
@@ -334,7 +329,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(bean, "intArray");
             fail("Should throw IllegalArgumentException 5");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 5");
         }
@@ -345,7 +340,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(null, "intIndexed", 0);
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -354,7 +349,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(bean, null, 0);
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -366,7 +361,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "intIndexed[0]");
             fail("Should throw IllegalArgumentException 3");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 3");
         }
@@ -375,7 +370,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(bean, "[0]");
             fail("Should throw NoSuchMethodException 4");
         } catch (NoSuchMethodException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of NoSuchMethodException 4");
         }
@@ -384,7 +379,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getIndexedProperty(bean, "intIndexed");
             fail("Should throw IllegalArgumentException 5");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 5");
         }
@@ -544,7 +539,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "intArray", -1);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -555,7 +550,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "intArray", 5);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -566,7 +561,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "intIndexed", -1);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -577,7 +572,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "intIndexed", 5);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -588,7 +583,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "listIndexed", -1);
             fail("Should have thrown IndexOutOfBoundsException");
         } catch (IndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IndexOutOfBoundsException");
         }
@@ -599,7 +594,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "listIndexed", 5);
             fail("Should have thrown IndexOutOfBoundsException");
         } catch (IndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IndexOutOfBoundsException");
         }
@@ -610,7 +605,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "stringArray", -1);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -621,7 +616,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "stringArray", 5);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -632,7 +627,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "stringIndexed", -1);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -643,7 +638,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                             "stringIndexed", 5);
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -663,7 +658,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "First Key");
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -672,7 +667,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getMappedProperty(bean, null, "First Key");
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -681,7 +676,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getMappedProperty(bean, "mappedProperty", null);
             fail("Should throw IllegalArgumentException 3");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 3");
         }
@@ -693,7 +688,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "mappedProperty(First Key)");
             fail("Should throw IllegalArgumentException 4");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 4");
         }
@@ -702,7 +697,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getMappedProperty(bean, "(Second Key)");
             fail("Should throw IllegalArgumentException 5");
         } catch (NoSuchMethodException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of NoSuchMethodException 5");
         }
@@ -711,7 +706,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getMappedProperty(bean, "mappedProperty");
             fail("Should throw IllegalArgumentException 6");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 6");
         }
@@ -907,7 +902,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getNestedProperty(null, "stringProperty");
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -916,7 +911,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getNestedProperty(bean, null);
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -1165,7 +1160,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
-            ; // Correct result for this test
+            // Correct result for this test
         }
 
     }
@@ -1180,7 +1175,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getSimpleProperty(null, "stringProperty");
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -1189,7 +1184,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.getSimpleProperty(bean, null);
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -1235,9 +1230,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             assertNotNull("Got a value", value);
             assertTrue("Got correct type", (value instanceof Double));
             assertEquals("Got correct value",
-                    ((Double) value).doubleValue(),
-                    (double) 321.0,
-                    (double) 0.005);
+                    ((Double) value).doubleValue(), 321.0, 0.005);
         } catch (IllegalAccessException e) {
             fail("IllegalAccessException");
         } catch (IllegalArgumentException e) {
@@ -1292,7 +1285,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (IllegalAccessException e) {
             fail("IllegalAccessException");
         } catch (IllegalArgumentException e) {
-            ; // Correct result for this test
+            // Correct result for this test
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
@@ -1342,7 +1335,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             assertTrue("Got correct type", (value instanceof Long));
             assertEquals("Got correct value",
                     ((Long) value).longValue(),
-                    (long) 321);
+                    321);
         } catch (IllegalAccessException e) {
             fail("IllegalAccessException");
         } catch (IllegalArgumentException e) {
@@ -1369,7 +1362,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (IllegalAccessException e) {
             fail("IllegalAccessException");
         } catch (IllegalArgumentException e) {
-            ; // Correct result for this test
+            // Correct result for this test
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
@@ -1448,7 +1441,9 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
-            ; // Correct result for this test
+            // Correct result for this test
+            assertEquals("Unknown property 'unknown' on dynaclass '" +
+                         ((DynaBean) bean).getDynaClass() + "'", e.getMessage() );
         }
 
     }
@@ -1466,7 +1461,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -1476,7 +1471,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -1489,7 +1484,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 3");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 3");
         }
@@ -1499,7 +1494,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw NoSuchMethodException 4");
         } catch (NoSuchMethodException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of NoSuchMethodException 4");
         }
@@ -1509,7 +1504,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 5");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 5");
         }
@@ -1521,7 +1516,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -1531,7 +1526,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -1544,7 +1539,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 3");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 3");
         }
@@ -1554,7 +1549,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw NoSuchMethodException 4");
         } catch (NoSuchMethodException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of NoSuchMethodException 4");
         }
@@ -1564,7 +1559,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(1));
             fail("Should throw IllegalArgumentException 5");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 5");
         }
@@ -1751,7 +1746,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(0));
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1762,7 +1757,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(0));
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1773,7 +1768,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(0));
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1784,7 +1779,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     new Integer(0));
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1795,7 +1790,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "New String");
             fail("Should have thrown IndexOutOfBoundsException");
         } catch (IndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IndexOutOfBoundsException");
         }
@@ -1806,7 +1801,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "New String");
             fail("Should have thrown IndexOutOfBoundsException");
         } catch (IndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IndexOutOfBoundsException");
         }
@@ -1817,7 +1812,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "New String");
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1828,7 +1823,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "New String");
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1839,7 +1834,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "New String");
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1850,7 +1845,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "New String");
             fail("Should have thrown ArrayIndexOutOfBoundsException");
         } catch (ArrayIndexOutOfBoundsException t) {
-            ; // Expected results
+            // Expected results
         } catch (Throwable t) {
             fail("Threw " + t + " instead of ArrayIndexOutOfBoundsException");
         }
@@ -1870,7 +1865,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "First Key", "First Value");
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -1880,7 +1875,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "First Value");
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -1890,7 +1885,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "First Value");
             fail("Should throw IllegalArgumentException 3");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 3");
         }
@@ -1903,7 +1898,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "First Value");
             fail("Should throw IllegalArgumentException 4");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 4");
         }
@@ -1913,7 +1908,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "Second Value");
             fail("Should throw IllegalArgumentException 5");
         } catch (NoSuchMethodException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of NoSuchMethodException 5");
         }
@@ -1923,7 +1918,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
                     "Third Value");
             fail("Should throw IllegalArgumentException 6");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 6");
         }
@@ -2031,7 +2026,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.setNestedProperty(null, "stringProperty", "");
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -2040,7 +2035,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.setNestedProperty(bean, null, "");
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -2204,7 +2199,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
-            ; // Correct result for this test
+            // Correct result for this test
         }
 
     }
@@ -2283,7 +2278,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
-            ; // Correct result for this test
+            // Correct result for this test
         }
 
     }
@@ -2325,7 +2320,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.setSimpleProperty(null, "stringProperty", "");
             fail("Should throw IllegalArgumentException 1");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 1");
         }
@@ -2334,7 +2329,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
             PropertyUtils.setSimpleProperty(bean, null, "");
             fail("Should throw IllegalArgumentException 2");
         } catch (IllegalArgumentException e) {
-            ; // Expected response
+            // Expected response
         } catch (Throwable t) {
             fail("Threw " + t + " instead of IllegalArgumentException 2");
         }
@@ -2438,7 +2433,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (IllegalAccessException e) {
             fail("IllegalAccessException");
         } catch (IllegalArgumentException e) {
-            ; // Correct result for this test
+            // Correct result for this test
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
@@ -2515,7 +2510,7 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (IllegalAccessException e) {
             fail("IllegalAccessException");
         } catch (IllegalArgumentException e) {
-            ; // Correct result for this test
+            // Correct result for this test
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
@@ -2598,7 +2593,9 @@ public class DynaPropertyUtilsTestCase extends TestCase {
         } catch (InvocationTargetException e) {
             fail("InvocationTargetException");
         } catch (NoSuchMethodException e) {
-            ; // Correct result for this test
+            // Correct result for this test
+            assertEquals("Unknown property 'unknown' on dynaclass '" +
+                         ((DynaBean) bean).getDynaClass() + "'", e.getMessage() );
         }
 
     }
